@@ -28,8 +28,9 @@ def cosel(coords = None, outcoords = None):
     return selout
 
 # someone may want to do this (if it's possible) instead of interpolation
-def datacosel(indata,start= None,end= None,step = None, coords = None, \
-           outstart = None, outend = None, outstep = None, outcoords = None):
+def datacosel(indata, coords = None outcoords = None, \
+              start= None,end= None,step = None,  \
+              outstart = None, outend = None, outstep = None):
     if (coords == None):
         coords = dtrange(start, end, step)
     if (outcoords == None):
@@ -40,7 +41,7 @@ def datacosel(indata,start= None,end= None,step = None, coords = None, \
     dataout = tile(None,len(cocosel))
     for iel, el in enumerate(cocosel):
         if (el != nan):
-            dataout[iel] = el
+            dataout[iel] = indata[el]
         else:
             dataout[iel] = nan
     return dataout
